@@ -7,12 +7,13 @@
 #' @param sequence Character or numeric vector listing sequence in which to add
 #' taxa. Randomized if not provided.
 #' @examples 
-#' data('Lobo', package = 'TreeTools')
+#' data("Lobo", package = "TreeTools")
 #' AdditionTree(Lobo.phy, concavity = 10)
 #' @template MRS
 #' @return `AdditionTree()` returns a tree of class `phylo`, rooted on
 #' `sequence[1]`.
-#' @importFrom TreeTools AddUnconstrained AddTipEverywhere PectinateTree
+#' @importFrom TreeTools AddUnconstrained AddTipEverywhere MatrixToPhyDat
+#' PectinateTree
 #' @importFrom cli cli_progress_bar cli_progress_update
 #' @family tree generation functions
 #' @seealso 
@@ -23,6 +24,7 @@
 #' [`TreeTools::ConstrainedNJ()`](https://ms609.github.io/TreeTools/reference/ConstrainedNJ)
 #' @export
 AdditionTree <- function (dataset, concavity = Inf, constraint, sequence) {
+  
   # Initialize missing parameters
   taxa <- names(dataset)
   if (missing(sequence)) {
@@ -30,10 +32,12 @@ AdditionTree <- function (dataset, concavity = Inf, constraint, sequence) {
   } else if (is.numeric(sequence)) {
     sequence <- taxa[sequence]
   }
+  
   nTaxa <- length(taxa)
   if (length(taxa) < 4) {
     return(PectinateTree(taxa))
   }
+  
   unlisted <- setdiff(taxa, sequence)
   if (length(unlisted) > 0) {
     sequence <- c(sequence, sample(unlisted))
@@ -41,15 +45,16 @@ AdditionTree <- function (dataset, concavity = Inf, constraint, sequence) {
   if (!missing(constraint)) {
     constraint <- AddUnconstrained(constraint, taxa)
   }
+  
   # PrepareDataXXX attributes only valid for full dataset
-  attr(dataset, 'info.amounts') <- NULL
-  attr(dataset, 'min.length') <- NULL
-  attr(dataset, 'informative') <- NULL
+  attr(dataset, "info.amounts") <- NULL
+  attr(dataset, "min.length") <- NULL
+  attr(dataset, "informative") <- NULL
   
   # Starting tree, rooted on first element in sequence
   tree <- PectinateTree(sequence[1:3])
   
-  cli_progress_bar('Addition tree', total = sum(2 * (4:nTaxa) - 5))
+  cli_progress_bar("Addition tree", total = sum(2 * (4:nTaxa) - 5))
   for (addition in sequence[4:nTaxa]) {
     candidates <- AddTipEverywhere(tree, addition)
     nCands <- length(candidates)
@@ -63,18 +68,24 @@ AdditionTree <- function (dataset, concavity = Inf, constraint, sequence) {
     }
     
     if (!missing(constraint)) {
+      if (!inherits(constraint, "phyDat")) {
+        if (is.numeric(constraint) && is.null(dim(constraint))) {
+          constraint <- t(constraint)
+        }
+        constraint <- MatrixToPhyDat(t(as.matrix(constraint)))
+      }
       thisConstr <- constraint[theseTaxa]
       morphyConstr <- PhyDat2Morphy(thisConstr)
       # Calculate constraint minimum score
       constraintLength <- sum(MinimumLength(thisConstr, compress = TRUE) *
-                              attr(thisConstr, 'weight'))
+                              attr(thisConstr, "weight"))
       
       .Forbidden <- function (edges) {
         preorder_morphy(edges, morphyConstr) != constraintLength
       }
       
     
-      candidates <- candidates[!vapply(lapply(candidates, `[[`, 'edge'),
+      candidates <- candidates[!vapply(lapply(candidates, `[[`, "edge"),
                                        .Forbidden, logical(1))]
       UnloadMorphy(morphyConstr)
     }
