@@ -1,27 +1,32 @@
-## Test cases designed by Thomas Guillerme
-
 test_that("Failures are graceful", {
   library("TreeTools", quietly = TRUE)
-  data('inapplicable.datasets')
+  data("inapplicable.datasets")
   dat <- inapplicable.phyData[[1]]
   unrooted <- RandomTree(dat, root = FALSE)
-  expect_error(TreeLength(unrooted, dat))
+  expect_error(TreeLength(unrooted, dat), "must be rooted")
+  expect_error(TreeLength(CollapseNode(RandomTree(dat, root = TRUE), 77), mo),
+               "must be binary")
   
   mo <- PhyDat2Morphy(dat)
   on.exit(mo <- UnloadMorphy(mo))
   
   sparse <- DropTip(RandomTree(dat, root = FALSE), 10)
-  expect_error(MorphyTreeLength(sparse, mo))
-  expect_error(MorphyTreeLength(sparse, NA))
+  expect_error(MorphyTreeLength(sparse, mo),
+               "Number of taxa .* not equal to number of tips")
+  expect_error(MorphyTreeLength(sparse, NA),
+               "a valid Morphy pointer")
   
-  expect_error(MorphyLength(sparse$edge[, 1], sparse$edge[, 2], mo, nTaxa = 0))
-  expect_error(MorphyLength(sparse$edge[, 1], sparse$edge[, 2], dat))
+  expect_error(MorphyLength(sparse$edge[, 1], sparse$edge[, 2], mo, nTaxa = 0),
+               mpl_translate_error(0))
+  expect_error(MorphyLength(sparse$edge[, 1], sparse$edge[, 2], dat),
+               "must be a Morphy pointer")
   
   expect_null(TreeLength(NULL))
+  
 })
 
 test_that("Deprecations throw warning", {
-  data('inapplicable.datasets')
+  data("inapplicable.datasets")
   dat <- inapplicable.phyData[[1]]
   tree <- TreeTools::RandomTree(dat, root = TRUE)
   expect_equal(TreeLength(tree, dat),
@@ -36,6 +41,7 @@ test_that("Morphy generates correct lengths", {
   tree <- ape::read.tree(text = "((((((1,2),3),4),5),6),(7,(8,(9,(10,(11,12))))));")
   relabel <- ape::read.tree(text = "((6,(5,(4,(3,(2,1))))),(7,(8,(9,(10,(11,12))))));")
   trees <- list(tree, relabel)
+  ## Test cases designed by Thomas Guillerme
   characters <- c("23--1??--032", # 0,  expect score = 5 
                   "1---1111---1", # 1,  expect score = 2
                   "1100----1100", # 2,  expect score = 3
@@ -97,11 +103,11 @@ test_that("Morphy generates correct lengths", {
   }
   
   ## Test combined matrix
-  bigPhy <- TreeTools::StringToPhyDat(paste0(characters, collapse = '\n'),
+  bigPhy <- TreeTools::StringToPhyDat(paste0(characters, collapse = "\n"),
                                       tree$tip.label, 
                                       byTaxon = FALSE)
   profPhy <- TreeTools::StringToPhyDat(paste0(characters[-c(15, 29, 34)],
-                                              collapse = '\n'),
+                                              collapse = "\n"),
                                        tree$tip.label, 
                                        byTaxon = FALSE)
   expect_identical(characters,
@@ -110,7 +116,7 @@ test_that("Morphy generates correct lengths", {
   expect_identical(paste0(collapse = '', 
                           vapply(characters, substr, start = 0, stop = 1,
                                  character(1))),
-                   substr(TreeTools::PhyToString(bigPhy, ps = ';',
+                   substr(TreeTools::PhyToString(bigPhy, ps = ";",
                                                  useIndex = TRUE,
                                                  byTaxon = TRUE,
                                                  concatenate = TRUE),
@@ -118,12 +124,12 @@ test_that("Morphy generates correct lengths", {
   
   morphyObj <- PhyDat2Morphy(bigPhy)
   moSummary <- summary(morphyObj)
-  expect_equal(c(length(bigPhy), attr(bigPhy, 'nr'), length(bigPhy) - 1),
+  expect_equal(c(length(bigPhy), attr(bigPhy, "nr"), length(bigPhy) - 1),
                c(moSummary$nTax, moSummary$nChar, moSummary$nInternal))
   tree_length <- MorphyTreeLength(tree, morphyObj)
   morphyObj <- UnloadMorphy(morphyObj)
   
-  expect_equal('0123', moSummary$allStates)
+  expect_equal("0123", moSummary$allStates)
   expect_equal(tree_length, sum(expected_results))
   expect_equal(tree_length, TreeLength(tree, bigPhy))
   expect_equal(tree_length, TreeLength(relabel, bigPhy))
@@ -136,8 +142,8 @@ test_that("Morphy generates correct lengths", {
   expect_equal(vapply(trees, TreeLength, double(1), bigPhy, concavity = 6),
                TreeLength(trees, bigPhy, concavity = 6))
   
-  expect_equal(vapply(trees, TreeLength, double(1), profPhy, concavity = 'p'),
-               TreeLength(trees, profPhy, concavity = 'profile'))
+  expect_equal(vapply(trees, TreeLength, double(1), profPhy, concavity = "p"),
+               TreeLength(trees, profPhy, concavity = "profile"))
   
 
   ## Run the bigger tree tests
@@ -160,30 +166,58 @@ test_that("Morphy generates correct lengths", {
 })
 
 test_that("(random) lists of trees are scored", {
-  data("congreveLamsdellMatrices", package = 'TreeSearch')
+  data("congreveLamsdellMatrices", package = "TreeSearch")
   mat <- congreveLamsdellMatrices[[42]]
   
   # Expected values calculated from 100k samples
   expect_gt(t.test(TreeLength(100, mat), mu = 318.5877)$p.val, 0.001)
   expect_gt(t.test(TreeLength(100, mat, 10L), mu = 17.16911)$p.val, 0.001)
-  expect_gt(t.test(TreeLength(100, mat, 'profile'), mu = 830.0585)$p.val, 0.001)
+  expect_gt(t.test(TreeLength(100, mat, "profile"), mu = 830.0585)$p.val, 0.001)
+})
+
+test_that("TreeLength() handles unrooted / non-preorder trees", {
+  library("TreeTools", quietly = TRUE)
+  data("congreveLamsdellMatrices", package = "TreeSearch")
+  mat <- congreveLamsdellMatrices[[42]]
+  
+  set.seed(0)
+  rand <- RandomTree(mat, root = TRUE)
+  scores <- TreeLength(c(rand, Postorder(rand)), mat)
+  expect_equal(scores[[1]], scores[[2]])
+  expect_equal(TreeLength(RootTree(Postorder(rand), 1), mat), scores[[1]])
+  expect_equal(TreeLength(RootTree(Preorder(rand), 1), mat), scores[[1]])
+  
+  set.seed(0)
+  unrooted <- RandomTree(mat, root = FALSE)
+  
+  expect_equal(expect_warning(TreeLength(c(unrooted), mat),
+                              "rooted on tip 1"),
+               TreeLength(c(RootTree(unrooted, 1)), mat))
+  
+  expect_equal(TreeLength(RootTree(Postorder(unrooted), 1), mat),
+               TreeLength(RootTree(unrooted, 1), mat))
+  scores <- expect_warning(
+    TreeLength(c(unrooted, Postorder(unrooted)), mat),
+    "rooted on tip 1")
+  expect_equal(scores[[1]], scores[[2]])
+  expect_equal(TreeLength(RootTree(unrooted, 1), mat), scores[[1]])
 })
 
 test_that("TreeLength() handles subsetted trees", {
-  data('inapplicable.datasets')
+  data("inapplicable.datasets")
   dat <- inapplicable.phyData[[1]] 
   t8 <- as.phylo(1:4, 8, tipLabels = names(dat)[1:8])
   expect_equal(4, length(TreeLength(t8, dat)))
 })
 
 test_that("Profile scoring is reported correctly", {
-  data('congreveLamsdellMatrices')
+  data("congreveLamsdellMatrices")
   dataset <- congreveLamsdellMatrices[[42]]
   prepDataset <- PrepareDataProfile(dataset)
   tree <- NJTree(prepDataset)
   edge <- Preorder(tree)$edge
   at <- attributes(prepDataset)
-  profiles <- attr(prepDataset, 'info.amounts')
+  profiles <- attr(prepDataset, "info.amounts")
   charSeq <- seq_along(prepDataset[[1]]) - 1L
   
   characters <- PhyToString(prepDataset, ps = '', useIndex = FALSE,
@@ -193,9 +227,9 @@ test_that("Profile scoring is reported correctly", {
   on.exit(morphyObjects <- vapply(morphyObjects, UnloadMorphy, integer(1)),
           add = TRUE)
   
-  expect_equal(TreeLength(tree, dataset, 'profile'),
-               TreeLength(tree, prepDataset, 'profile'))
-  expect_equal(TreeLength(tree, dataset, 'profile'),
+  expect_equal(TreeLength(tree, dataset, "profile"),
+               TreeLength(tree, prepDataset, "profile"))
+  expect_equal(TreeLength(tree, dataset, "profile"),
                morphy_profile(edge, morphyObjects, startWeights, charSeq, 
                               profiles, Inf))
 })
@@ -203,10 +237,10 @@ test_that("Profile scoring is reported correctly", {
 test_that("CharacterLength() fails gracefully", {
   expect_error(CharacterLength(as.phylo(1, 8), 1))
   
-  data('inapplicable.datasets')
+  data("inapplicable.datasets")
   dataset <- inapplicable.phyData[[12]]
   # Unlabelled leaves
-  expect_error(CharacterLength(structure(list(), class = 'phylo'), dataset))
+  expect_error(CharacterLength(structure(list(), class = "phylo"), dataset))
   
   # Missing leaves
   expect_error(CharacterLength(as.phylo(1, 4), dataset))
@@ -214,8 +248,8 @@ test_that("CharacterLength() fails gracefully", {
   expect_equal(CharacterLength(tMinus1, dataset[-1]),
                CharacterLength(tMinus1, dataset))
   expect_error(CharacterLength(as.phylo(1, 43), dataset))
-  tPlus1 <- as.phylo(1, 44, tipLabels = c('extra', names(dataset)))
-  expect_equal(CharacterLength(DropTip(tPlus1, 'extra'), dataset),
+  tPlus1 <- as.phylo(1, 44, tipLabels = c("extra", names(dataset)))
+  expect_equal(CharacterLength(DropTip(tPlus1, "extra"), dataset),
                CharacterLength(tPlus1, dataset))
   expect_error(CharacterLength(as.phylo(1:2, 43, tipLabels = names(dataset)),
                                dataset))
@@ -229,7 +263,7 @@ test_that("CharacterLength() fails gracefully", {
 })
 
 test_that("Character compression works", {
-  data('inapplicable.datasets')
+  data("inapplicable.datasets")
   dataset <- inapplicable.phyData[[12]]
   tree <- TreeTools::NJTree(dataset)
   expect_equal(137, length(CharacterLength(tree, dataset)))
